@@ -11,11 +11,13 @@ def create_dir(dir_path: Path) -> None:
 
 
 def delete_dir(dir_path: Path) -> None:
-    rmtree(dir_path)
+    if dir_path.exists():
+        rmtree(dir_path)
 
 
 def delete_file(file_path: Path) -> None:
-    file_path.unlink()
+    if file_path.exists():
+        file_path.unlink()
 
 
 def search_files(path_regex: Path = Path("*")) -> List[Path]:
